<template>
    <div class="container-fluid bg-white position-absolute top-0 start-0" style="z-index: 100; height: 100%;">
      <div class="container pa-4">
        <div class="no-print border-bottom py-2 text-end actions">
          <button class="mr-4 btn btn-secondary btn-sm" type="button" @click="router.back"><i class="bi bi-arrow-left-short"></i> Back</button>
          <button class="mr-4 btn btn-primary btn-sm" type="button" @click="printPage"><i class="bi bi-printer"></i> Print Page</button>
        </div>

        <div class="row invoice-provider">
          <div class="col-7">
            <h2>{{ provider.name }}</h2>
            <div>{{ provider.address_line_1 }}</div>
            <div>{{ provider.address_line_2 }}</div>
            <div>{{ provider.admin_area_2 }}, {{ provider.admin_area_1 }} &nbsp; {{ provider.postal_code }}, {{ getCountry (provider.country_code) }}</div>
          </div>
          <div class="col-5 text-end">
            <h3>Invoice</h3>
            <h6>{{ invoiceNo }}</h6>
          </div>
        </div>


        <div class="row mt-10 invoice-billto">
          <h4>Bill To</h4>

          <div class="row">
            <div class="col-4 fw-bold">Company</div>
            <div class="col-8">{{ profile.company_name }}</div>
          </div>

          <div class="row">
            <div class="col-4 fw-bold">Contact</div>
            <div class="col-8">{{ profile.name }}</div>
          </div>

          <div class="row">
            <div class="col-4 fw-bold">Address</div>
            <div class="col-8">
              <div>{{ order.address_line_1 }}</div>
              <div>{{ order.address_line_2 }}</div>
              <div>{{ order.admin_area_2 }}, {{ order.admin_area_1 }} &nbsp; {{ order.postal_code }}, {{ getCountry (order.country_code) }}</div>
            </div>
          </div>

          <div class="row">
            <div class="col-4 fw-bold">Account ID</div>
            <div class="col-8">G{{ (state.$uid + '').zfill (5) }}</div>
          </div>

          <div class="row">
            <div class="col-4 fw-bold">Purchase Order#</div>
            <div class="col-8">{{ order.order_id }}</div>
          </div>

          <div class="row">
            <div class="col-4 fw-bold">Invoice Date</div>
            <div class="col-8">{{ new Date (order.creation_date).format ("%b %d, %Y %H:%M") }}</div>
          </div>

          <div class="row">
            <div class="col-4 fw-bold">Terms</div>
            <div class="col-8">Due On Receipt</div>
          </div>
        </div>



        <table class="table table-bordered table-striped mt-8 invoice-items">
          <thead>
            <tr class="table-secondary">
              <th scope="col">Description</th>
              <th scope="col" class="text-end">Quantity</th>
              <th scope="col" class="text-end">Unit Price</th>
              <th scope="col" class="text-end">Amount</th>
            </tr>
          </thead>
          <tbody>
            <tr>
              <td>Credit for road pavement analysis</td>
              <td class="text-end">{{ parseInt (order.quantity).format () }}</td>
              <td class="text-end">USD {{ order.unit_price }}</td>
              <td class="text-end">USD {{ parseFloat (order.amount).format ('usd') }}</td>
            </tr>
            <tr v-for="i in 2">
              <th>&nbsp;</th>
              <td></td>
              <td></td>
              <td></td>
            </tr>
            <tr>
              <td colspan="3" class="text-end"><b>Credit Price</b></td>
              <td colspan="1" class="text-end">USD {{ parseFloat (order.amount - order.tax).format ('usd') }}</td>
            </tr>
            <tr>
              <td colspan="3" class="text-end"><b>Tax</b></td>
              <td colspan="1" class="text-end">USD {{ parseFloat (order.tax).format ('usd') }}</td>
            </tr>
            <tr>
              <td colspan="3" class="text-end"><b>Amount Total</b></td>
              <td colspan="1" class="text-end table-warning">USD {{ parseFloat (order.amount).format ('usd') }}</td>
            </tr>
          </tbody>
        </table>

        <div class="row my-10">
          <h4>Payment Options</h4>
          <div>Debit / credit card at <a href="https://kracknet.com/credit">https://kracknet.com/credit</a></div>
          <div>Paypal email address: semiconnetworks@gmail.com</div>
        </div>
      </div>
    </div>
</template>



<script setup>
const route = useRoute ()
const router = useRouter ()
const { state } = useStore ()
const order = ref ({})
const profile = ref ({})
const provider = ref ({})

async function updateContent (id) {
  let resp = null
  resp = await backend.get ('GET_ORDER', {order_id: id})
  order.value = resp.data
  resp = await backend.get ('GET_PROFILES')
  profile.value = resp.data
  resp = await backend.get ("WEBCONTENTS_CONFIGS", {keys: 'SEMICON_NETWORKS'})
  provider.value = JSON.parse (resp.data.SEMICON_NETWORKS.json_val)
}

function printPage () {
  window.print ()
}

function getCountry (code) {
  const countries = backend.get_spec ("EDIT_PROFILES").argspecs.ARGS.country.codein
  const name = countries.find((element) => element [0] === code)
  if (name == undefined) return code
  return name [1]
}

onMounted (async () => {
  updateContent (route.params.id)
})

const invoiceNo = computed (() => {
  return `#INV${new Date ().format ('%y')}-${(order.value.id + '').zfill (5)}`
})

watch (() => route.params, (newVal, oldVal) => {
  if (!newVal.id) return
  updateContent (newVal.id)
})
</script>







<script>
export default {
  beforeRouteEnter (to, from, next) {
    frontend.permission.required (['user'], {path: '/members/signin'}, {to, from, next})
  }
}
</script>
